# -*- encoding: utf-8 -*-

import os
from paste.script import templates
from paste.script.templates import var

RENOMMAGES = {'gitignore' : '.gitignore'}

class DjangoTemplate(templates.Template):
    """
    Modèle de projet Django pour l'AUF reposant sur `Buildout <http://www.buildout.org/>`_.

    Il permet de construire un projet avec les briques de base importantes pour la maintenance
    et l'homogénéité entre les applications, avec notamment:


        * Un framework de migration (South)

        * La charte graphique de l'AUF

        * La Recette AUF pour préparer le projet Django


    **Utilisation**::

        paster create -t auf_django


    **Les fichiers squelettes**:

    *buildout.cfg*

    .. literalinclude:: ../auf/skeleton/django/templates/django/buildout.cfg_tmpl

    *devel.cfg*

    .. literalinclude:: ../auf/skeleton/django/templates/django/devel.cfg_tmpl

    """
    egg_plugins = ['auf.skeleton.django']
    summary = 'Démarrer un nouveau projet Django avec Buildout'
    _template_dir = 'templates/django'
    use_cheetah = True

    vars = [
    ]

    def post(self, command, output_dir, vars):
        for avant, apres in RENOMMAGES.items():
            avant = os.path.join(output_dir, avant)
            apres = os.path.join(output_dir, apres)
            os.rename(avant, apres)           
        print "----------------------------------------------------------------"
        print "Génération du projet terminée."
        print ""
        print "################### AVERTISSEMENTS #############################"
        print "* Paquets requis : "
        print "     - python-virtualenv (environement Python de DEV)"
        print "     - python-mysqldb (connecteur Python SQL)"
        print "     - git-core (Gestionnaire de sources)"
        print ""
        print "* Assurez-vous d'avoir chargé votre environement virtuel (DEV)"
        print "################################################################"
        print ""
        print "* : cd %s (aller dans le nouveau projet)" % output_dir
        print "* : python bootstrap.py (pour récupérer buildout et setuptools)"
        print "* : bin/buildout -c devel.cfg (pour boostraper le projet Django)"
        print "* : Configurer les accès MySQL dans conf.py"
        print "* : bin/django syncdb (créer les tables)"
        print "* : bin/django migrate (initialiser les incréments de migration)"
        print "* : 'Pusher' le projet dans le reposoire git centralisé"
        print ""
        print "----------------------------------------------------------------"
